@@ -35,15 +35,15 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kpushbutton.h>
 #include <ktextedit.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <kdebug.h>
 #include <kprogress.h>
-#include <kglobal.h>
-#include <kconfig.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -169,7 +169,7 @@ KEquityPriceUpdateDlg::KEquityPriceUpdateDlg(TQWidget *parent, const TQString& s
 
   // previous versions of this dialog allowed to store a "Don't ask again" switch.
   // Since we don't support it anymore, we just get rid of it
-  KConfig* config = KGlobal::config();
+  TDEConfig* config = TDEGlobal::config();
   config->setGroup("Notification Messages");
   config->deleteEntry("KEquityPriceUpdateDlg::slotQuoteFailed::Price Update Failed");
 }
@@ -217,7 +217,7 @@ void KEquityPriceUpdateDlg::addPricePair(const MyMoneySecurityPair& pair, bool d
       }
 
       if(keep) {
-        KListViewItem* item = new KListViewItem(lvEquityList,
+        TDEListViewItem* item = new TDEListViewItem(lvEquityList,
           symbol,
           i18n("%1 units in %2").arg(pair.first,pair.second));
         if(pr.isValid()) {
@@ -251,7 +251,7 @@ void KEquityPriceUpdateDlg::addInvestment(const MyMoneySecurity& inv)
     }
     // if it is in use, it_a is not equal to list.end()
     if(it_a != list.end()) {
-      KListViewItem* item = new KListViewItem(lvEquityList, symbol, inv.name());
+      TDEListViewItem* item = new TDEListViewItem(lvEquityList, symbol, inv.name());
       MyMoneySecurity currency = file->currency(inv.tradingCurrency());
       MyMoneyPrice pr = file->price(id.utf8(), inv.tradingCurrency());
       if(pr.isValid()) {
@@ -365,7 +365,7 @@ void KEquityPriceUpdateDlg::storePrices(void)
     ft.commit();
 
   } catch(MyMoneyException *e) {
-    qDebug("Unable to add price information for %s", name.data());
+    tqDebug("Unable to add price information for %s", name.data());
     delete e;
   }
 }
@@ -523,7 +523,7 @@ void KEquityPriceUpdateDlg::slotReceivedQuote(const TQString& _id, const TQStrin
           }
         }
       }
-      item->setText(PRICE_COL, KGlobal::locale()->formatMoney(price, sec.tradingSymbol(), KMyMoneyGlobalSettings::pricePrecision()));
+      item->setText(PRICE_COL, TDEGlobal::locale()->formatMoney(price, sec.tradingSymbol(), KMyMoneyGlobalSettings::pricePrecision()));
       item->setText(DATE_COL, date.toString(Qt::ISODate));
       logStatusMessage(i18n("Price for %1 updated (id %2)").arg(_symbol,_id));
       // make sure to make OK button available
